pub struct EnumVariant {
pub discriminant: i128,
pub rust_name: &'static str,
pub sql_name: &'static str,
}Available on crate feature
i-implement-a-third-party-backend-and-opt-into-breaking-changes only.Expand description
Metadata for an enum variant produced by diesel-derive in the #[derive(Enum)] macro
Fields
discriminant: i128The discriminant value of the given enum variant
rust_name: &'static strThe rust side name of the given enum variant
sql_name: &'static strThe sql side name of the given enum variant