pub struct IntMapping<T, ST>(/* private fields */);Available on crate feature
i-implement-a-third-party-backend-and-opt-into-breaking-changes only.Expand description
Map enum variants to INTEGER (in different sizes) by converting each variant to the relevant
discriminant value
The generic type T specifies the Rust side integer type, while the generic type ST
specifies the SQL side integer type. Both need to match
This mapping variant requires to specify explicit discriminant values for all enum variants